/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: properties.h 3129 2007-02-17 10:31:55Z b_lindeijer $
 */

#ifndef _TMW_PROPERTIES_H_
#define _TMW_PROPERTIES_H_

#include <map>
#include <string>
#include <sstream>

/**
 * A class holding a set of properties.
 */
class Properties
{
    public:
        virtual
        ~Properties() {}

        /**
         * Get a map property.
         *
         * @param def default value, empty string by default
         * @return the value of the given property or the given default when it
         *         doesn't exist.
         */
        const std::string&
        getProperty(const std::string &name, const std::string &def = "")
        {
            PropertyMap::const_iterator i = mProperties.find(name);
            return (i != mProperties.end()) ? i->second : def;
        }

        /**
         * Gets a map property as a float.
         *
         * @param def default value, 0.0f by default
         * @return the value of the given property, or 0.0f when it doesn't
         *         exist.
         */
        const float
        getFloatProperty(const std::string &name, float def = 0.0f)
        {
            PropertyMap::const_iterator i = mProperties.find(name);
            float ret = def;
            if (i != mProperties.end())
            {
                std::stringstream ss;
                ss.str(i->second);
                ss >> ret;
            }
            return ret;
        }

        /**
         * Returns whether a certain property is available.
         */
        bool
        hasProperty(const std::string &name)
        {
            return (mProperties.find(name) != mProperties.end());
        }

        /**
         * Set a map property.
         */
        void
        setProperty(const std::string &name, const std::string &value)
        {
            mProperties[name] = value;
        }

    private:
        typedef std::map<std::string, std::string> PropertyMap;
        PropertyMap mProperties;
};

#endif
